﻿using System;
using System.Collections.Generic;
using VCinemaApi.Models;

namespace VCinemaApi.Data
{
    public class MockScreenRepository : IScreenRepository
    {
        private static List<Screen> _screens = new List<Screen>
        {
            new Screen
            {
                Id = 0,
                Name = "Kirby's Screen",
                Source = "https://vcinema.b-cdn.net/Shrek.mp4",
                Playing = true,
                Position = 1337.0,
                LastModified = new DateTime(2020, 03, 11, 17, 30, 00)
            },
            new Screen
            {
                Id = 1,
                Name = "Jack's Screen",
                Source = "https://vcinema.b-cdn.net/The%20Fanatic.mp4",
                Playing = true,
                Position = 69420.00,
                LastModified = new DateTime(2020, 03, 20, 19, 31, 04)
            }
        };

        public void CreateScreen(Screen screen)
        {
            _screens.Add(screen);
        }

        public void UpdateScreen(Screen newScreen)
        {
            var screen = GetScreenById(newScreen.Id);
            screen.Name = newScreen.Name;
            screen.Source = newScreen.Source;
            screen.Playing = newScreen.Playing;
            screen.Position = newScreen.Position;
            screen.LastModified = DateTime.UtcNow;
        }

        public IEnumerable<Screen> GetScreens()
        {
            return _screens;
        }

        public Screen GetScreenById(int id)
        {
            return _screens.Find(screen => screen.Id == id);
        }

        public void SetPlayingById(int id, bool playing)
        {
            var screen = GetScreenById(id);
            screen.Playing = playing;
        }

        public bool GetPlayingById(int id)
        {
            var screen = GetScreenById(id);
            return screen.Playing;
        }

        public void SetPositionById(int id, double position)
        {
            var screen = GetScreenById(id);
            screen.Position = position;
        }

        public double GetPositionById(int id)
        {
            var screen = GetScreenById(id);
            return screen.Position;
        }

        public double GetCurrentPositionById(int id)
        {
            var screen = GetScreenById(id);
            var elapsed = DateTime.UtcNow - screen.LastModified;
            return elapsed.TotalSeconds + screen.Position;
        }

        public bool SaveChanges()
        {
            return true;
        }
    }
}