﻿using System;
using System.Collections.Generic;
using VCinemaApi.Models;

namespace VCinemaApi.Data
{
    public class ScreenRepository : IScreenRepository
    {
        private VCinemaContext _context;

        public ScreenRepository(VCinemaContext context)
        {
            _context = context;
        }

        public void CreateScreen(Screen screen)
        {
            _context.Screens.Add(screen);
        }

        public void UpdateScreen(Screen newScreen)
        {
            var screen = GetScreenById(newScreen.Id);
            screen.Name = newScreen.Name;
            screen.Source = newScreen.Source;
            screen.Playing = newScreen.Playing;
            screen.Position = newScreen.Position;
            screen.LastModified = DateTime.UtcNow;
        }

        public IEnumerable<Screen> GetScreens()
        {
            return _context.Screens;
        }

        public Screen GetScreenById(int id)
        {
            return _context.Screens.Find(id);
        }

        public void SetPlayingById(int id, bool playing)
        {
            var screen = GetScreenById(id);
            screen.Playing = playing;
        }

        public bool GetPlayingById(int id)
        {
            var screen = GetScreenById(id);
            return screen.Playing;
        }

        public void SetPositionById(int id, double position)
        {
            var screen = GetScreenById(id);
            screen.Position = position;
        }

        public double GetPositionById(int id)
        {
            var screen = GetScreenById(id);
            return screen.Position;
        }

        public double GetCurrentPositionById(int id)
        {
            var screen = GetScreenById(id);
            var elapsed = DateTime.UtcNow - screen.LastModified;
            return elapsed.TotalSeconds + screen.Position;
        }

        public bool SaveChanges()
        {
            return (_context.SaveChanges() >= 0);
        }
    }
}
